@@ -1,12 +1,12 @@
 package Bencher::Scenario::DigestSHA::SHA256;
 
-our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 sub _create_file {
     my ($size) = @_;
@@ -46,9 +46,9 @@ our $scenario = {
 
         my $dss = $sc->{datasets};
         for my $ds (@$dss) {
-            $log->infof("Creating temporary file with size of %.1fMB ...", $ds->{_size}/1024/1024);
+            log_info("Creating temporary file with size of %.1fMB ...", $ds->{_size}/1024/1024);
             my $filename = _create_file($ds->{_size});
-            $log->infof("Created file %s", $filename);
+            log_info("Created file %s", $filename);
             $ds->{args}{filename} = $filename;
         }
     },
@@ -61,7 +61,7 @@ our $scenario = {
         for my $ds (@$dss) {
             my $filename = $ds->{args}{filename};
             next unless $filename;
-            $log->infof("Unlinking %s", $filename);
+            log_info("Unlinking %s", $filename);
             unlink $filename;
         }
     },
@@ -82,7 +82,7 @@ Bencher::Scenario::DigestSHA::SHA256 - Benchmark Digest::SHA against sha512sum
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::DigestSHA::SHA256 (from Perl distribution Bencher-Scenarios-DigestSHA), released on 2017-01-25.
+This document describes version 0.003 of Bencher::Scenario::DigestSHA::SHA256 (from Perl distribution Bencher-Scenarios-DigestSHA), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -106,7 +106,7 @@ Version numbers shown below are the versions used when running the sample benchm
 
 L<String::ShellQuote> 1.04
 
-L<Digest::SHA> 5.95
+L<Digest::SHA> 5.96
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -140,17 +140,17 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
+Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m DigestSHA::SHA256 >>):
 
  #table1#
- +-------------+-----------+-----------+------------+---------+---------+
- | participant | rate (/s) | time (ms) | vs_slowest |  errors | samples |
- +-------------+-----------+-----------+------------+---------+---------+
- | sha256sum   |       5.5 |       180 |          1 | 0.0014  |       6 |
- | Digest::SHA |       5.5 |       180 |          1 | 0.00037 |       6 |
- +-------------+-----------+-----------+------------+---------+---------+
+ +-------------+-----------+-----------+------------+-----------+---------+
+ | participant | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +-------------+-----------+-----------+------------+-----------+---------+
+ | Digest::SHA |      4.5  |       220 |       1    |   0.00024 |       7 |
+ | sha256sum   |      4.65 |       215 |       1.03 | 7.2e-05   |       6 |
+ +-------------+-----------+-----------+------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m DigestSHA::SHA256 --module-startup >>):
@@ -159,9 +159,9 @@ Benchmark module startup overhead (C<< bencher -m DigestSHA::SHA256 --module-sta
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Digest::SHA         | 0.83                         | 4.1                | 16             |      13   |                    8   |        1   | 9.1e-05 |       7 |
- | String::ShellQuote  | 1.5                          | 4.9                | 21             |       8.9 |                    3.9 |        1.5 | 7.1e-05 |       6 |
- | perl -e1 (baseline) | 1                            | 4.3                | 16             |       5   |                    0   |        2.6 | 9.8e-06 |       6 |
+ | Digest::SHA         | 0.83                         | 4.2                | 20             |     14    |                   8.61 |       1    | 3.1e-05 |       6 |
+ | String::ShellQuote  | 1.5                          | 5                  | 25             |      9.5  |                   4.11 |       1.4  | 4.1e-05 |       8 |
+ | perl -e1 (baseline) | 1.03                         | 4.43               | 20.2           |      5.39 |                   0    |       2.52 | 4.5e-06 |       6 |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
@@ -191,7 +191,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
