@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::DigestSHA::SHA512;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -8,20 +8,20 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00075,
+        errors => 7.7e-05,
         participant => "Digest::SHA",
-        rate => 7.1,
-        samples => 7,
-        time => 140,
+        rate => 6.02,
+        samples => 6,
+        time => 166,
         vs_slowest => 1,
       },
       {
-        errors => 0.0015,
+        errors => 0.0002,
         participant => "sha512sum",
-        rate => 8,
+        rate => 6.9,
         samples => 6,
-        time => 100,
-        vs_slowest => 1,
+        time => 150,
+        vs_slowest => 1.1,
       },
     ],
     {
@@ -69,7 +69,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -92,7 +91,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -100,20 +98,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -122,30 +116,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2600.062,
-                                              stepping                     => 4,
+                                              speed                        => 3293.992,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -184,7 +164,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -207,7 +186,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -215,20 +193,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -237,30 +211,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2863.382,
-                                              stepping                     => 4,
+                                              speed                        => 3249.308,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -299,7 +259,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -322,7 +281,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -330,20 +288,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -352,30 +306,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2600.062,
-                                              stepping                     => 4,
+                                              speed                        => 3264.808,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -414,7 +354,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -437,7 +376,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -445,20 +383,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -467,41 +401,27 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2896.687,
-                                              stepping                     => 4,
+                                              speed                        => 3294.113,
+                                              stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 1.9849419593811,
+      "func.elapsed_time"              => 2.36653113365173,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => 1.034,
+                                            "__PACKAGE__" => 1.039,
                                             "Bencher::Scenario::DigestSHA::SHA512" => undef,
-                                            "Benchmark::Dumb" => "0.10",
+                                            "Benchmark::Dumb" => 0.111,
                                             "Devel::Platform::Info" => 0.16,
-                                            "Digest::SHA" => 5.95,
-                                            "perl" => "v5.24.0",
+                                            "Digest::SHA" => 5.96,
+                                            "perl" => "v5.26.0",
                                             "String::ShellQuote" => 1.04,
                                             "Sys::Info" => 0.78,
                                           },
@@ -509,36 +429,36 @@ our $results = [
       "func.permute"                   => ["perl", ["perl"], "participant", [0, 1], "dataset", [0]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "rosa",
+                                            codename => "jessie",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.19.0-32-generic",
+                                            kernel   => "linux-3.16.0-4-amd64",
                                             kname    => "Linux",
-                                            kvers    => "3.19.0-32-generic",
+                                            kvers    => "3.16.0-4-amd64",
                                             osflag   => "linux",
-                                            oslabel  => "LinuxMint",
+                                            oslabel  => "Debian",
                                             osname   => "GNU/Linux",
-                                            osvers   => 17.3,
+                                            osvers   => "8.0",
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
-                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
+                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.19.0-32-generic",
+                                                          "uname -r"        => "3.16.0-4-amd64",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
       "func.precision"                 => 6,
       "func.scenario_module"           => "Bencher::Scenario::DigestSHA::SHA512",
-      "func.scenario_module_md5sum"    => "65d71277b3ce257bf3bdb140e8ef38f7",
-      "func.scenario_module_mtime"     => 1479736943,
-      "func.scenario_module_sha1sum"   => "1fcdbea1ba8ad3f1abacc48edce601be92fee49d",
-      "func.scenario_module_sha256sum" => "3aa5ea87fed9124c30ec71a124f50dacb2e5cd09b047d19c55ea3cf46811abfc",
-      "func.time_end"                  => 1485329460.40585,
+      "func.scenario_module_md5sum"    => "5f78ea3dd9a623c1a6b5caa324601d4d",
+      "func.scenario_module_mtime"     => 1499687192,
+      "func.scenario_module_sha1sum"   => "8459cc78f4b613b7c788471cd38c0b752eaaa864",
+      "func.scenario_module_sha256sum" => "015d83841d4d626b53ef68bbdba6e280f9f15fc43d03d3e36ca79576a61fcc8e",
+      "func.time_end"                  => 1499687228.70135,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1485329458.42091,
+      "func.time_start"                => 1499687226.33482,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s", "ms"],
       "table.fields"                   => ["participant", "rate", "time", "vs_slowest", "errors", "samples"],
